@@ -29,11 +29,16 @@ class Service(object):
 
     def _can_be_scaled(self):
 
-        if self._service.name == 'master':
+        if self._service.name == 'master' or self._service.name == 'dsh':
             raise CouldNotScale(self._service.name)
         else:
             return True
 
+    def is_scaleable(self):
+        if self._service.name == 'master' or self._service.name == 'dsh':
+            return False
+        else:
+            return True
 
     @property
     def machines(self):
